hwndOwner property
A handle to the window that owns the dialog box. This member can be any valid window handle, or it can be null if the dialog box has no owner.
Implementation
external Pointer hwndOwner;
A handle to the window that owns the dialog box. This member can be any valid window handle, or it can be null if the dialog box has no owner.
external Pointer hwndOwner;