nMaxFileTitle property
The size, in characters, of the buffer pointed to by lpstrFileTitle. This member is ignored if lpstrFileTitle is null.
Implementation
@Uint32()
external int nMaxFileTitle;
The size, in characters, of the buffer pointed to by lpstrFileTitle. This member is ignored if lpstrFileTitle is null.
@Uint32()
external int nMaxFileTitle;